@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -66,7 +66,8 @@ class SignalsHelper():
             @param callback_str as str
         """
         callback = getattr(self, callback_str)
-        self.__allow_duplicate.append(callback)
+        if callback not in self.__allow_duplicate:
+            self.__allow_duplicate.append(callback)
 
     def init(self, signals):
         """
@@ -98,8 +99,8 @@ class SignalsHelper():
         """
         for (obj, signal, callback_str) in signals:
             if obj is None:
-                Logger.warning("Can't connect signal: %s -> %s",
-                               signal, callback_str)
+                Logger.debug("Can't connect signal: %s -> %s",
+                             signal, callback_str)
                 continue
             name = "%s_%s" % (obj, signal)
             if name in self._connected.keys():
