@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -116,7 +116,7 @@ class TodayBannerWidget(BannerWidget, SignalsHelper):
         return [
                 (App().window.container.widget, "notify::folded",
                  "_on_container_folded"),
-                (App().art, "album-artwork-changed",
+                (App().album_art, "album-artwork-changed",
                  "_on_album_artwork_changed")
         ]
 
